@@ -238,11 +238,11 @@ class ReferenceBrowserPopup(BrowserView):
     def getResult(self):
         assert self._updated
         result = []
+        qc = getMultiAdapter((self.context, self.request),
+                             name='refbrowser_querycatalog')
         if self.widget.show_results_without_query or self.search_text:
             if self.widget.restrict_browsing_to_startup_directory:
                 pass
-            qc = getMultiAdapter((self.context, self.request),
-                                 name='refbrowser_querycatalog')
             result = (self.widget.show_results_without_query or \
                       self.search_text) and \
                       qc(search_catalog=self.widget.search_catalog)
@@ -253,8 +253,11 @@ class ReferenceBrowserPopup(BrowserView):
             ploneview = getMultiAdapter((self.context, self.request),
                                         name="plone")
             folder = ploneview.getCurrentFolder()
-            result = folder.getFolderContents(
-                        contentFilter={'sort_on': 'sortable_title'})
+            self.request.form['path'] = {
+                              'query': '/'.join(folder.getPhysicalPath()),
+                              'depth':1}
+            self.request.form['portal_type'] = []
+            result = qc(search_catalog=self.widget.search_catalog)
         else:
             result = []
         b_size = int(self.request.get('b_size', 20))
